Package: IRTM
Title: Theory-Driven Item Response Theory (IRT) Models
Version: 0.0.1.2
Authors@R: 
    c(person(given = "Marco",
           family = "Morucci",
           role = "aut",
           email = "moruccim@msu.edu"),
    person(given = "Margaret",
           family = "Foster",
           role = "aut",
            email = "m.jenkins.foster@gmail.com",
           comment = c(ORCID = "0000-0002-6418-8394")),
    person(given = "David",
           family = "Siegel",
           role = c("aut", "cre"),
	   email = "david.siegel@duke.edu",
           comment = c(ORCID = "0000-0003-1619-6119")))
Description: IRT-M is a semi-supervised approach based on Bayesian Item Response Theory
    that produces theoretically identified underlying dimensions from input data
    and a constraints matrix. The methodology is fully described in 'Morucci et al. (2024),
    "Measurement That Matches Theory: Theory-Driven Identification in Item Response Theory Models"'. 
    Details are available at <https://www.cambridge.org/core/journals/american-political-science-review/article/measurement-that-matches-theory-theorydriven-identification-in-item-response-theory-models/395DA1DFE3DCD7B866DC053D7554A30B>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: truncnorm, tmvtnorm, utils, RcppProgress, RcppDist, ggplot2, R
        (>= 3.5.0)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), RColorBrewer,
        fastDummies, ggrepel, tidyverse, spelling
VignetteBuilder: knitr
LazyData: true
LinkingTo: Rcpp, RcppArmadillo, RcppDist, RcppProgress
Imports: coda, Rcpp, RcppArmadillo, ggridges, rlang, dplyr, reshape2,
Config/testthat/edition: 3
Language: en-US
NeedsCompilation: yes
Packaged: 2026-04-20 12:46:32 UTC; Promachos
Author: Marco Morucci [aut],
  Margaret Foster [aut] (ORCID: <https://orcid.org/0000-0002-6418-8394>),
  David Siegel [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1619-6119>)
Maintainer: David Siegel <david.siegel@duke.edu>
Repository: CRAN
Date/Publication: 2026-04-21 06:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 13:39:29 UTC; unix
Archs: IRTM.so.dSYM
