# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

sample_constrained_irt <- function(Y, d, nu0, S0, lbs, ubs, ind, theta_fix, nburn, nsamp, thin, learn_Sigma, learn_Omega, display_progress) {
    .Call(`_IRTM_sample_constrained_irt`, Y, d, nu0, S0, lbs, ubs, ind, theta_fix, nburn, nsamp, thin, learn_Sigma, learn_Omega, display_progress)
}

